[llvm-commits] [llvm] r135448 - in /llvm/trunk: include/llvm/CodeGen/MachineModuleInfo.h lib/CodeGen/MachineModuleInfo.cpp

Bill Wendling isanbard at gmail.com
Mon Jul 18 17:00:58 PDT 2011


Author: void
Date: Mon Jul 18 19:00:58 2011
New Revision: 135448

URL: http://llvm.org/viewvc/llvm-project?rev=135448&view=rev
Log:
Rename CompactEncoding to CompactUnwindEncoding.

Modified:
    llvm/trunk/include/llvm/CodeGen/MachineModuleInfo.h
    llvm/trunk/lib/CodeGen/MachineModuleInfo.cpp

Modified: llvm/trunk/include/llvm/CodeGen/MachineModuleInfo.h
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/include/llvm/CodeGen/MachineModuleInfo.h?rev=135448&r1=135447&r2=135448&view=diff
==============================================================================
--- llvm/trunk/lib/CodeGen/MachineModuleInfo.cpp (original)
+++ llvm/trunk/lib/CodeGen/MachineModuleInfo.cpp Mon Jul 18 19:00:58 2011
@@ -257,7 +257,7 @@
                                      const MCRegisterInfo &MRI,
                                      const TargetAsmInfo *TAI)
   : ImmutablePass(ID), Context(MAI, MRI, TAI),
-    ObjFileMMI(0), CompactEncoding(0), CurCallSite(0), CallsEHReturn(0),
+    ObjFileMMI(0), CompactUnwindEncoding(0), CurCallSite(0), CallsEHReturn(0),
     CallsUnwindInit(0), DbgInfoAvailable(false),
     CallsExternalVAFunctionWithFloatingPointArguments(false) {
   initializeMachineModuleInfoPass(*PassRegistry::getPassRegistry());
@@ -312,7 +312,7 @@
   FilterEnds.clear();
   CallsEHReturn = 0;
   CallsUnwindInit = 0;
-  CompactEncoding = 0;
+  CompactUnwindEncoding = 0;
   VariableDbgInfo.clear();
 }
 





More information about the llvm-commits mailing list
--- llvm/trunk/include/llvm/CodeGen/MachineModuleInfo.h (original)
+++ llvm/trunk/include/llvm/CodeGen/MachineModuleInfo.h Mon Jul 18 19:00:58 2011
@@ -111,9 +111,9 @@
   // frame maps by debug and exception handling consumers.
   std::vector<MachineMove> FrameMoves;
 
-  // CompactEncoding - If the target supports it, this is the compact unwind
-  // encoding. It replaces a function's CIE and FDE.
-  uint32_t CompactEncoding;
+  // CompactUnwindEncoding - If the target supports it, this is the compact
+  // unwind encoding. It replaces a function's CIE and FDE.
+  uint32_t CompactUnwindEncoding;
 
   // LandingPads - List of LandingPadInfo describing the landing pad information
   // in the current function.
@@ -234,10 +234,10 @@
   /// handling comsumers.
   std::vector<MachineMove> &getFrameMoves() { return FrameMoves; }
 
-  /// getCompactEncoding - Returns the compact unwind encoding for a function if
-  /// the target supports the encoding. This encoding replaces a function's CIE
-  /// and FDE.
-  uint32_t getCompactEncoding() const { return CompactEncoding; }
+  /// getCompactUnwindEncoding - Returns the compact unwind encoding for a
+  /// function if the target supports the encoding. This encoding replaces a
+  /// function's CIE and FDE.
+  uint32_t getCompactUnwindEncoding() const { return CompactUnwindEncoding; }
 
   /// getAddrLabelSymbol - Return the symbol to be used for the specified basic
   /// block when its address is taken.  This cannot be its normal LBB label

Modified: llvm/trunk/lib/CodeGen/MachineModuleInfo.cpp
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/lib/CodeGen/MachineModuleInfo.cpp?rev=135448&r1=135447&r2=135448&view=diff
==============================================================================